@@ -1,14 +1,17 @@
 from io import StringIO
-from typing import List, Optional
+from typing import List, Optional, Tuple
 
 from nonebot.adapters.onebot.v11 import Message, MessageSegment
 
-from nonebot_plugin_mahjong_scoreboard.controller.mapper import season_state_mapping
+from nonebot_plugin_mahjong_scoreboard.controller.mapper import season_state_mapping, digit_mapping
 from nonebot_plugin_mahjong_scoreboard.model.orm import data_source
+from nonebot_plugin_mahjong_scoreboard.model.orm.game import GameRecordOrm, GameOrm
 from nonebot_plugin_mahjong_scoreboard.model.orm.group import GroupOrm
-from nonebot_plugin_mahjong_scoreboard.model.orm.season import SeasonUserPointOrm, SeasonOrm
+from nonebot_plugin_mahjong_scoreboard.model.orm.season import SeasonUserPointOrm, SeasonOrm, \
+    SeasonUserPointChangeLogOrm
 from nonebot_plugin_mahjong_scoreboard.model.orm.user import UserOrm
 from nonebot_plugin_mahjong_scoreboard.service.group_service import get_user_nickname
+from nonebot_plugin_mahjong_scoreboard.utils.rank import ranked
 
 
 async def map_season_user_point(sup: SeasonUserPointOrm,
@@ -48,7 +51,7 @@ async def map_season_user_point(sup: SeasonUserPointOrm,
         return Message(MessageSegment.text(io.getvalue()))
 
 
-async def map_season_user_points(season: SeasonOrm, sups: List[SeasonUserPointOrm]) -> List[Message]:
+async def map_season_user_points(group: GroupOrm, season: SeasonOrm, sups: List[SeasonUserPointOrm]) -> List[Message]:
     session = data_source.session()
 
     messages = []
@@ -64,10 +67,7 @@ async def map_season_user_points(season: SeasonOrm, sups: List[SeasonUserPointOr
     pending_message.write(season_state_mapping[season.state])
     pending_message.write("\n\n")
 
-    group = await session.get(GroupOrm, season.group_id)
-
-    rank = 1
-    for i, sup in enumerate(sups):
+    for rank, sup in ranked(sups, key=lambda sup: sup.point, reverse=True):
         user = await session.get(UserOrm, sup.user_id)
         name = await get_user_nickname(user, group)
 
@@ -78,10 +78,6 @@ async def map_season_user_points(season: SeasonOrm, sups: List[SeasonUserPointOr
             point_text = '±'
         point_text += str(sup.point)
 
-        # 同分同名次
-        if i > 0 and sup.point != sups[i - 1].point:
-            rank = i + 1
-
         line = f"#{rank}  {name}    {point_text}\n"
         pending_message.write(line)
         pending += 1
@@ -95,3 +91,34 @@ async def map_season_user_points(season: SeasonOrm, sups: List[SeasonUserPointOr
         messages.append(Message(MessageSegment.text(pending_message.getvalue().strip())))
 
     return messages
+
+
+async def map_season_user_trend(group: GroupOrm, user: UserOrm, season: SeasonOrm,
+                                result: List[Tuple[SeasonUserPointChangeLogOrm, GameOrm, GameRecordOrm]]) -> Message:
+    with StringIO() as sio:
+        sio.write("用户[")
+        sio.write(await get_user_nickname(user, group))
+        sio.write("]在赛季[")
+        sio.write(season.name)
+        sio.write("]的最近走势如下：\n")
+
+        for log, game, record in result:
+            sio.write("  ")
+
+            sio.write(digit_mapping[record.rank])
+            sio.write("位    ")
+
+            sio.write(str(record.score))
+            sio.write('点  (')
+            if record.point > 0:
+                sio.write('+')
+            elif record.point == 0:
+                sio.write('±')
+            sio.write(str(record.point))
+            sio.write(')  ')
+
+            sio.write("对局")
+            sio.write(str(game.code))
+            sio.write("\n")
+
+        return Message(MessageSegment.text(sio.getvalue().strip()))
